/*	SAS GLOBAL 2017 - E-POSTER #406
	SAMPLE PROJECT CODE USED FOR E-POSTER AND PAPER 
	PAUL HILLIARD
	EDUCATIONAL TESTING SERVICE (ETS)	*/


*Some important options;
options nonumber nodate; /* no page numbers */
options ps=60 ls=72; /* these are good page size and line size codes*/
options spool symbolgen mlogic;	*This centers my output and gives me some other macro options;

dm'log;clear;out;clear'; *clears my log and output windows;

libname SASGlob "C:\MAT8414\SAS Global - 2017 Submission\Data";

/* Dataset meant for predicting recommended placement status for adolescents admitted to hospital with psychiatric problem 
Variables:	1. PLACE: recommended placement period - - Outpatient (0), Day    
  	   Treatment (1), Intermediate Residential (2), Residential (3) 
		2. PLACE3: Same as above but combining outpatient and day 
   treatment categories
		3. AGE: Age in years
		4. RACE: Race (0=white, 1=nonwhite)
		5. GENDER: Gender (0=female, 1=male)
		6. NEURO: Neuropsychiatric disturbance - - None (0), Mild (1), 
         Moderate (2), Severe (3)
		7. EMOT: emotional disturbance - - not severe (0), severe (1)
		8. DANGER: danger to others - - unlikely (0), possible (1), 
   probable (2), likely (3)
		9. ELOPE: elopement risk - - no risk (0), risk (1)
		10. LOS: length of hosipitalization in days
		11. BEHAV: behavioral symptoms score (from 0 to 9)
		12. CUSTD: state custody - - N0 (0), Yes (1)
		13. VIOL: history of violence - - N0 (0), Yes (1) */

proc import datafile="C:\MAT8414\SAS Global - 2017 Submission\SAS_Global_2017_Dataset_Adolescent.csv" 
out=SasGlob.SASGlobal_2017 dbms=csv replace; 
getnames=yes; 
run;

proc freq data=SasGlob.SASGlobal_2017;
table place place3;
run;

*Select 100 of the responses as a "Validation Set" for the resulting models;
*Seed=535113001 gives me the data for this paper;

proc surveyselect data=SASGlob.SASGlobal_2017 seed=535113001
method=srs sampsize=100 out=SasGlob.SASGlobal_XV;
run;

data SASGlob.SASGlobal_MB;
merge SASGlob.SASGlobal_2017 (in=a) SASGlob.SASGlobal_XV (in=b);
by ID;
if a and not b;
run;
/* 
   PLACEMENT=0	OUTPATIENT
   PLACEMENT=1	DAY TREATMENT
   PLACEMENT=2	INTERMEDIATE RESIDENTIAL
   PLACEMENT=3	RESIDENTIAL
*/

**THE FOLLOWING UTILIZES ONLY 3 PLACEMENT LEVELS - not used for paper;

*Using 3-level Placement - 408 responses;
*Cumulative Logit Model assuming Proportional Odds;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_PROPODDS;
	model PLACE3 = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=STEPWISE SLE=0.10 SLS=0.10; 
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_PROPODDS;
	ods output association=SasGlob.SASGlobal_assoc_PROPODDS;
run;
quit;

proc freq data=SasGlob.Pred_XV_PROPODDS;
	table F_PLACE3*I_PLACE3 / nopercent norow nocol agree(WT=FC);
run;

*Partial Proportional Odds;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_PPODDS;
	model PLACE3 = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=STEPWISE SLE=0.10 SLS=0.10
	equalslopes unequalslopes details maxiter=10000;
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_PPODDS;
	ods output association=SasGlob.SASGlobal_assoc_PPODDS;
run;
quit;

proc freq data=SasGlob.Pred_XV_PPODDS;
	table F_PLACE3*I_PLACE3 / nopercent norow nocol agree(WT=FC);
run;

*GENERAL CUMULATIVE LOGIT;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_GEN;
	model PLACE3 = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=STEPWISE SLE=0.10 SLS=0.10
	unequalslopes maxiter=100;
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_GEN;
	ods output association=SasGlob.SASGlobal_assoc_GEN;
run;
quit;

proc freq data=SasGlob.Pred_XV_GEN;
	table F_PLACE3*I_PLACE3 / nopercent norow nocol agree(WT=FC);
run;

*FOUR-PLACEMENT LEVEL models - here is my project code;
*Cumulative Logit Model assuming Proportional Odds;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_4PROPODDS;
	model PLACE = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=STEPWISE SLE=0.10 SLS=0.10; 
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_4PROPODDS;
	ods output association=SasGlob.SASGlobal_assoc_4PROPODDS;
run;
quit;

proc freq data=SasGlob.Pred_XV_4PROPODDS;
	table F_PLACE*I_PLACE / nopercent norow nocol agree(WT=FC);
		label F_PLACE="TRUE PLACEMENT";
	label I_PLACE="PREDICTED PLACEMENT";
run;

*Plots of non-proportionality for CUSTD, EMOT and BEHAV;
*CUSTD;

proc logistic data=SasGlob.SASGlobal_MB; 
	model PLACE = CUSTD / LINK=CLOGIT ; 
run;
quit;

proc freq data=sasglob.sasglobal_MB;
	table custd*place / out=os;
run;

proc transpose data=os out=tran;
	by custd;
	var count;
run;

data a;
	set tran;
constant=0;
Outpatient=log((sum(of col1-col1) + constant)/(sum(of col2-col4)+constant));
Day_Treat=log((sum(of col1-col2) + constant)/(sum(of col3-col4)+constant));
Inter_Residential=log((sum(of col1-col3) + constant)/(sum(of col4-col4)+constant));
run;

proc sgplot data=a;
	series y=Outpatient x=custd;
	series y=Day_Treat x=custd;
	series y=Inter_Residential x=custd;
	yaxis values =(-5 to 5) label="Empirical Logits for State Custody variable";
	xaxis integer label="State Custody variable (0=No   1=Yes)";
run;
*EMOT variable;

proc logistic data=SasGlob.SASGlobal_MB; 
	model PLACE = EMOT / LINK=CLOGIT ; 
run;
quit;

proc freq data=sasglob.sasglobal_MB;
	table emot*place / out=os2;
run;

proc transpose data=os2 out=tran2;
	by emot;
	var count;
run;

data b; set tran2;
constant=0;
Outpatient=log((sum(of col1-col1) + constant)/(sum(of col2-col4)+constant));
Day_Treat=log((sum(of col1-col2) + constant)/(sum(of col3-col4)+constant));
Inter_Residential=log((sum(of col1-col3) + constant)/(sum(of col4-col4)+constant));
run;

proc sgplot data=b;
	series y=Outpatient x=emot;
	series y=Day_Treat x=emot;
	series y=Inter_Residential x=emot;
	yaxis values =(-5 to 5) label="Empirical Logits for Emotional Disturbance variable";
	xaxis integer label="Emotional Disturbance variable (0=Not Severe   1=Severe)";
run;
*BEHAV;

proc logistic data=SasGlob.SASGlobal_MB; 
	model PLACE = BEHAV / LINK=CLOGIT ; 
run;
quit;

proc freq data=sasglob.sasglobal_MB;
	table behav*place / out=os3;
run;

proc transpose data=os3 out=tran3;
	by behav;
	var count;
run;

data c; set tran3;
constant=0.5;
Outpatient=log((sum(of col1-col1) + constant)/(sum(of col2-col4)+constant));
Day_Treat=log((sum(of col1-col2) + constant)/(sum(of col3-col4)+constant));
Inter_Residential=log((sum(of col1-col3) + constant)/(sum(of col4-col4)+constant));
run;

proc sgplot data=c;
	series y=Outpatient x=behav;
	series y=Day_Treat x=behav;
	series y=Inter_Residential x=behav;
	yaxis values =(-5 to 5) label="Empirical Logits for Behavioral Symptoms Score";
	xaxis integer values=(0 to 9 by 1) label="Score from 0 - 9 on Behavioral Symptoms Scale";
run;

*Partial Proportional Odds - my model;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_4PPODDS;
	model PLACE = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=STEPWISE SLE=0.10 SLS=0.10
	equalslopes unequalslopes details maxiter=10000;
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_4PPODDS;
	ods output association=SasGlob.SASGlobal_assoc_4PPODDS;
run;
quit;

proc freq data=SasGlob.Pred_XV_4PPODDS;
	table F_PLACE*I_PLACE / nopercent norow nocol agree(WT=FC);
	label F_PLACE="TRUE PLACEMENT";
	label I_PLACE="PREDICTED PLACEMENT";
run;

*Can you do forward or backward too? YES YOU CAN!!!;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_4PPODDS_FW;
	model PLACE = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=FORWARD SLE=0.10 SLS=0.10
	equalslopes unequalslopes details maxiter=10000;
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_4PPODDS_FW;
	ods output association=SasGlob.SASGlobal_assoc_4PPODDS_FW;
run;
quit;

proc freq data=SasGlob.Pred_XV_4PPODDS_FW;
	table F_PLACE*I_PLACE / nopercent norow nocol agree(WT=FC);
	label F_PLACE="TRUE PLACEMENT";
	label I_PLACE="PREDICTED PLACEMENT";
run;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_4PPODDS_BW;
	model PLACE = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=BACKWARD SLE=0.10 SLS=0.10
	equalslopes unequalslopes details maxiter=10000;
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_4PPODDS_BW;
	ods output association=SasGlob.SASGlobal_assoc_4PPODDS_BW;
run;
quit;

proc freq data=SasGlob.Pred_XV_4PPODDS_BW;
	table F_PLACE*I_PLACE / nopercent norow nocol agree(WT=FC);
	label F_PLACE="TRUE PLACEMENT";
	label I_PLACE="PREDICTED PLACEMENT";
run;

*How about it all equal slopes are included?;

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_4PPODDS_INC;
	model PLACE = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=STEPWISE SLE=0.10 SLS=0.10
	equalslopes unequalslopes include=equalslopes details maxiter=10000;
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_4PPODDS_INC;
	ods output association=SasGlob.SASGlobal_assoc_4PPODDS_INC;
run;
quit;

proc freq data=SasGlob.Pred_XV_4PPODDS_INC;
	table F_PLACE*I_PLACE / nopercent norow nocol agree(WT=FC);
	label F_PLACE="TRUE PLACEMENT";
	label I_PLACE="PREDICTED PLACEMENT";
run;

*FINALLY FOR ALL LEVELS FOR ALL VARIABLES (GENERAL CUMULATIVE LOGIT);

proc logistic data=SasGlob.SASGlobal_MB outest=SASGlobal_est_4GEN;
	model PLACE = AGE RACE GENDER NEURO EMOT DANGER ELOPE LOS BEHAV CUSTD VIOL / LINK=CLOGIT SELECTION=STEPWISE SLE=0.10 SLS=0.10
	unequalslopes maxiter=100;
	score data=SasGlob.SASGlobal_XV out=SasGlob.Pred_XV_4GEN;
	ods output association=SasGlob.SASGlobal_assoc_4GEN;
run;
quit;

proc freq data=SasGlob.Pred_XV_4GEN;
	table F_PLACE*I_PLACE / nopercent norow nocol agree(WT=FC);
run;

